import numpy as np


def get_fake_ssro_data(
    num_shots: int,
    g_centroid: complex = 10e-3 + 10e-3j,
    e_centroid: complex = 30e-3 + 30e-3j,
    measurement_noise: float = 0.01,
) -> list[np.array]:
    """Generate mock data for an SSRO experiment."""
    real_part1 = np.random.normal(loc=g_centroid.real, scale=measurement_noise, size=num_shots)
    imag_part1 = np.random.normal(loc=g_centroid.imag, scale=measurement_noise, size=num_shots)
    real_part2 = np.random.normal(loc=e_centroid.real, scale=measurement_noise, size=num_shots)
    imag_part2 = np.random.normal(loc=e_centroid.imag, scale=measurement_noise, size=num_shots)

    ground_population = real_part1 + imag_part1 * 1j
    excited_population = real_part2 + imag_part2 * 1j

    result: list[complex] = list()
    for a, b in zip(ground_population, excited_population):
        result.append(a)
        result.append(b)

    result = np.asarray(result, dtype=complex)
    return [np.real(result), np.imag(result)]


def get_fake_binary_ssro_data(
    num_shots: int, p_ground: float = 0.95, p_excited: float = 0.95
) -> list[np.array]:
    """Generate mock data for a discriminated SSRO experiment."""
    ground_state_measurements = np.random.binomial(n=1, p=1 - p_ground, size=num_shots)
    excited_state_measurements = np.random.binomial(n=1, p=p_excited, size=num_shots)

    result: list[complex] = list()
    for a, b in zip(ground_state_measurements, excited_state_measurements):
        result.append(a)
        result.append(b)

    result = np.asarray(result, dtype=float)
    return [result, np.zeros_like(result) * float("nan")]
